# Welcome to Blackwall Protocol, Netrunner

Blackwall allows you to submit RACF and TSO commands, manage users, create or modify dataset profiles, and manage general resource profiles.

## Getting started

To get started start a new tab by pressing one of the buttons on the right, they will open up some cool tabs for you to check out.
Also consider reading the documentation: <https://emmasbox.github.io/blackwall-protocol-docs/>.

## Share the love

If you enjoy Blackwall Protocol please star it on <https://github.com/EmmasBox/blackwall-protocol>. Blackwall is made possible thanks to the CBTTape project.
